<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>ArcTangential</name>
    <message>
        <location filename="../ArcTangential.js" line="+63"/>
        <source>Choose base line or base arc</source>
        <translation>Vyberte základnú čiaru alebo základný oblúk</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Choose end point of arc</source>
        <translation>Zvoľte koncový bod oblúka</translation>
    </message>
    <message>
        <location filename="../ArcTangential.ui" line="+17"/>
        <source>Radius:</source>
        <translation>Polomer:</translation>
    </message>
    <message>
        <location filename="../ArcTangentialInit.js" line="+2"/>
        <source>&amp;Tangentially Connected</source>
        <translation>&amp;Dotyčnicovo pripojený</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc tangential to base entity</source>
        <translation>Nakreslite dotyčnicový oblúk k základnému prvku</translation>
    </message>
</context>
</TS>
